summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/3rdparty/sqlite/hash.c
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/3rdparty/sqlite/hash.c')
-rw-r--r--experimental/tqtinterface/qt4/src/3rdparty/sqlite/hash.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/experimental/tqtinterface/qt4/src/3rdparty/sqlite/hash.c b/experimental/tqtinterface/qt4/src/3rdparty/sqlite/hash.c
index 06650c1e5..b96d40ded 100644
--- a/experimental/tqtinterface/qt4/src/3rdparty/sqlite/hash.c
+++ b/experimental/tqtinterface/qt4/src/3rdparty/sqlite/hash.c
@@ -5,7 +5,7 @@
** a legal notice, here is a blessing:
**
** May you do good and not evil.
** May you tqfind forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
*************************************************************************
@@ -200,7 +200,7 @@ static void rehash(Hash *pH, int new_size){
** hash table that matches the given key. The hash for this key has
** already been computed and is passed as the 4th parameter.
*/
-static HashElem *tqfindElementGivenHash(
+static HashElem *findElementGivenHash(
const Hash *pH, /* The pH to be searched */
const void *pKey, /* The key we are searching for */
int nKey,
@@ -268,7 +268,7 @@ void *sqliteHashFind(const Hash *pH, const void *pKey, int nKey){
assert( xHash!=0 );
h = (*xHash)(pKey,nKey);
assert( (pH->htsize & (pH->htsize-1))==0 );
- elem = tqfindElementGivenHash(pH,pKey,nKey, h & (pH->htsize-1));
+ elem = findElementGivenHash(pH,pKey,nKey, h & (pH->htsize-1));
return elem ? elem->data : 0;
}
@@ -280,7 +280,7 @@ void *sqliteHashFind(const Hash *pH, const void *pKey, int nKey){
** flag is set. NULL is returned.
**
** If another element already exists with the same key, then the
-** new data tqreplaces the old data and the old data is returned.
+** new data replaces the old data and the old data is returned.
** The key is not copied in this instance. If a malloc fails, then
** the new data is returned and the hash table is unchanged.
**
@@ -300,7 +300,7 @@ void *sqliteHashInsert(Hash *pH, const void *pKey, int nKey, void *data){
hraw = (*xHash)(pKey, nKey);
assert( (pH->htsize & (pH->htsize-1))==0 );
h = hraw & (pH->htsize-1);
- elem = tqfindElementGivenHash(pH,pKey,nKey,h);
+ elem = findElementGivenHash(pH,pKey,nKey,h);
if( elem ){
void *old_data = elem->data;
if( data==0 ){
@@ -5,7 +5,7 @@
**
** May you do good and not evil.
-** May you tqfind forgiveness for yourself and forgive others.
+** May you find forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**